<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Back-end functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function nm_admin_main
 * @action back-end main panel (manage posts and settings)
 */
function nm_admin_panel() {
  include(NMTEMPLATEPATH . 'panel_header.php');
  $posts = nm_get_posts(TRUE);
  if (!empty($posts)) {
    echo '<table class="highlight">';
    include(NMTEMPLATEPATH . 'panel_table_header.php');
    foreach ($posts as $id=>$file) {
      $url = nm_get_url('post') . $id;
      $data = getXML($file);
      $title = cl($data->title);
      $date = shtDate($data->date);
      include(NMTEMPLATEPATH . 'panel_table_row.php');
    }
    echo '</table>';
  }
  echo '<p><b>' . count($posts) . '</b> ' . i18n_r("news_manager/POSTS") . '</p>';
}


/*******************************************************
 * @function nm_edit_post
 * @param $id - unique post id
 * @action edit or create new posts
 */
function nm_edit_post($id) {
  $file = NMDATAPATH . $id . '.xml';
  $data = @getXML($file);
  $title = @stripslashes($data->title);
  $private = @$data->private != '' ? 'checked' : '';
  $tags = @str_replace(',', ', ', ($data->tags));
  $content = @stripslashes($data->content);
  include(NMTEMPLATEPATH . 'edit_post.php');
  if (file_exists($file)) {
    $date = date(i18n_r('DATE_AND_TIME_FORMAT'), filemtime($file));
    echo '<small>' . i18n_r('news_manager/LAST_SAVED') . ": $date</small>";
  }
  include(NMTEMPLATEPATH . 'ckeditor.php');
}


/*******************************************************
 * @function nm_save_post
 * @action write $_POST data to xml file
 */
function nm_save_post() {
  if ($_POST['post-title'] == '') {
    nm_display_message(i18n_r('news_manager/ERROR_EMPTY_POST'), TRUE);
  } else {
    # collect $_POST data
    $id = $_POST['post-id'];
    $file = NMDATAPATH . $id . '.xml';
    $title = safe_slash_html($_POST['post-title']);
    $private = isset($_POST['post-private']) ? 'Y' : '';
    $content = safe_slash_html($_POST['post-content']);
    # filter tags
    $tags = safe_slash_html($_POST['post-tags']);
    $tags = str_replace(' ', '', $tags);    # remove whitespace
    $tags = str_replace(',,', ',', $tags);  # remove empty tags
    # set the right date
    if (!file_exists($file)) {
      $date = date('r');
    } else {
      $data = getXML($file);
      $date = $data->date;
    }
    # create xml object
    $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
    $obj = $xml->addChild('title');
    $obj->addCData($title);
    $obj = $xml->addChild('date');
    $obj->addCData($date);
    $obj = $xml->addChild('private');
    $obj->addCData($private);
    $obj = $xml->addChild('tags');
    $obj->addCData($tags);
    $obj = $xml->addChild('content');
    $obj->addCData($content);
    # write data to file
    if (!@XMLsave($xml, $file))
      nm_display_message(i18n_r('news_manager/ERROR_SAVE_POST'), TRUE);
    else
      nm_display_message(i18n_r('news_manager/SUCCESS_SAVE_POST'));
  }
}


/*******************************************************
 * @function nm_delete_post
 * @param $id - unique post id
 * @action deletes the requested post
 */
function nm_delete_post($id) {
  $file = NMDATAPATH . $id . '.xml';
  if (file_exists($file))
    unlink($file);
  if (file_exists($file))
    nm_display_message(i18n_r('news_manager/ERROR_DELETE_POST'), TRUE);
  else
    nm_display_message(i18n_r('news_manager/SUCCESS_DELETE_POST'));
}


?>
