<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * General functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function is_pos_int
 * @return TRUE when $value is a positive integer, FALSE otherwise
 */
function is_pos_int($value) {
  return is_numeric($value) && $value > 0;
}


/*******************************************************
 * @function nm_uniqid
 * @return a new unique post identifier
 */
function nm_uniqid() {
  $posts = nm_get_posts(TRUE);
  return intval(key($posts)) + 1;
}


/*******************************************************
 * @function nm_get_url
 * @return url of front-end newspage, with optional query
 */
function nm_get_url($query=FALSE) {
  global $SITEURL, $NMPAGEURL;
  $url = $SITEURL . 'index.php';
  if ($NMPAGEURL != 'index')
    $url .= '?id=' . $NMPAGEURL;
  if ($query)
    $url .= $NMPAGEURL != 'index' ? "&$query=" : "?$query=";
  return $url;
}


/*******************************************************
 * @function nm_get_posts
 * @param $private when TRUE include private posts
 * @return array with posts in the NMDATAPATH folder
 */
function nm_get_posts($private=FALSE) {
  $posts = array();
  $files = getFiles(NMDATAPATH);
  foreach ($files as $file) {
    if (isFile($file, NMDATAPATH, 'xml')) {
      if (!$private) {
        $data = getXML(NMDATAPATH . $file);
        if ($data->private == 'Y')
          continue;
      }
      $id = basename($file, '.xml');
      $posts[$id] = NMDATAPATH . $file;
    }
  }
  krsort($posts);
  return $posts;
}



/*******************************************************
 * @function nm_get_archives
 * @return array with monthly archives
 */
function nm_get_archives() {
  $archives = array();
  $posts = nm_get_posts();
  foreach ($posts as $id=>$file) {
    $data = getXML($file);
    $date = strtotime($data->date);
    $title = date('F Y', $date);
    $archive = date('Ym', $date);
    if (!array_key_exists($archive, $archives))
      $archives[$archive] = $title;
  }
  krsort($archives);
  return $archives;
}


/*******************************************************
 * @function nm_get_tags
 * @return array with unique tags (keys) and counts (values)
 */
function nm_get_tags() {
  $tags = array();
  $posts = nm_get_posts();
  foreach ($posts as $id=>$file) {
    $data = getXML($file);
    if (!empty($data->tags))
      $tags = array_merge($tags, explode(',', $data->tags));
  }
  sort($tags);
  return array_count_values($tags);
}


/*******************************************************
 * @function nm_create_excerpt
 * @param $content the post content
 * @return a truncated version of the post content
 */
function nm_create_excerpt($content) {
  global $NMEXCERPTLENGTH;
  $len = intval($NMEXCERPTLENGTH);
  $content = strip_tags($content);
  if (strlen($content) > $len) {
    if (function_exists('mb_substr'))
      $content = trim(mb_substr($content, 0, $len)) . ' [...]';
    else
      $content = trim(substr($content, 0, $len)) . ' [...]';
  }
  return "<p>$content</p>";
}


/*******************************************************
 * @function nm_display_message
 * @param $msg a string containing the message
 * @param $error if TRUE, show as $msg as error, else as update
 * @action display status messages on back-end pages
 */
function nm_display_message($msg, $error=FALSE) {
  if (isset($msg)) {
    ?>
    <script type="text/javascript">
      $(function() {
        $('div.bodycontent').before('<div class="<?php echo $error ? 'error' : 'updated'; ?>" style="display:block;">'+
          <?php echo json_encode($msg); ?>+'</div>');
        $(".updated, .error").fadeOut(500).fadeIn(500);
      });
    </script>
    <?php
  }
}


?>
