<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Back-end configuration functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function nm_env_check
 * @action check plugin environment (config & folder)
 */
function nm_env_check() {
  $config = !file_exists(NMCONFIG) ? nm_write_config_file() : TRUE;
  $folder = !file_exists(NMDATAPATH) ? nm_create_data_folder() : TRUE;
  if (!$config || !$folder)
    echo '<p>' . i18n_r('news_manager/ERROR_ENV') . '</p>';
  return ($config && $folder);
}


/*******************************************************
 * @function nm_write_config_file
 * @action write plugin settings to config file
 */
function nm_write_config_file() {
  global $NMPAGEURL, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
  $obj = $xml->addChild('page_url');
  $obj->addCData($NMPAGEURL);
  $obj = $xml->addChild('show_excerpt');
  $obj->addCData($NMSHOWEXCERPT);
  $obj = $xml->addChild('excerpt_length');
  $obj->addCData($NMEXCERPTLENGTH);
  $obj = $xml->addChild('posts_per_page');
  $obj->addCData($NMPOSTSPERPAGE);
  $obj = $xml->addChild('recent_posts');
  $obj->addCData($NMRECENTPOSTS);
  return @XMLsave($xml, NMCONFIG);
}


/*******************************************************
 * @function nm_create_data_folder
 * @action create the folder /data/posts and make it writable
 */
function nm_create_data_folder() {
  if (mkdir(NMDATAPATH, 0777)) {
    $fh = fopen(NMDATAPATH . '.htaccess', 'w');
    fwrite($fh, 'Deny from all');
    fclose($fh);
    return TRUE;
  } else {
    return FALSE;
  }
}


/*******************************************************
 * @function nm_edit_settings
 * @action edit plugin configuration settings
 */
function nm_edit_settings() {
  global $NMPAGEURL, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  include(NMTEMPLATEPATH . 'edit_settings.php');
}


/*******************************************************
 * @function nm_save_settings
 * @action parse POST data and save to config file
 */
function nm_save_settings() {
  global $NMPAGEURL, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  # parse $_POST
  $NMPAGEURL = $_POST['page_url'];
  $NMSHOWEXCERPT = $_POST['show_excerpt'] ? 'Y' : '';
  if (is_pos_int($_POST['excerpt_length']))
    $NMEXCERPTLENGTH = $_POST['excerpt_length'];
  if (is_pos_int($_POST['posts_per_page']))
    $NMPOSTSPERPAGE = $_POST['posts_per_page'];
  if (is_pos_int($_POST['recent_posts']))
    $NMRECENTPOSTS = $_POST['recent_posts'];
  # write settings to file
  if (!nm_write_config_file())
    nm_display_message(i18n_r('news_manager/ERROR_SAVE_CONFIG'), TRUE);
  else
    nm_display_message(i18n_r('news_manager/SUCCESS_SAVE_CONFIG'));
}


?>
